@@ -615,10 +615,13 @@ const completion: Fig.Spec = {
       name: "edit",
       options: [
         {
-          name: "--output",
+          name: "--no-headers",
         },
         {
-          name: "--no-headers",
+          name: "--in-place",
+        },
+        {
+          name: "--output",
         },
         {
           name: ["-h", "--help"],
@@ -1619,6 +1622,138 @@ const completion: Fig.Spec = {
             },
           ],
         },
+        {
+          name: "iplookup",
+          options: [
+            {
+              name: "--new-column",
+            },
+            {
+              name: "--rename",
+            },
+            {
+              name: "--country",
+            },
+            {
+              name: "--min-score",
+            },
+            {
+              name: "--admin1",
+            },
+            {
+              name: "--k_weight",
+            },
+            {
+              name: "--formatstr",
+            },
+            {
+              name: "--language",
+            },
+            {
+              name: "--invalid-result",
+            },
+            {
+              name: "--jobs",
+            },
+            {
+              name: "--batch",
+            },
+            {
+              name: "--timeout",
+            },
+            {
+              name: "--cache-dir",
+            },
+            {
+              name: "--languages",
+            },
+            {
+              name: "--cities-url",
+            },
+            {
+              name: "--force",
+            },
+            {
+              name: "--output",
+            },
+            {
+              name: "--delimiter",
+            },
+            {
+              name: "--progressbar",
+            },
+            {
+              name: ["-h", "--help"],
+              description: "Print help",
+            },
+          ],
+        },
+        {
+          name: "iplookupnow",
+          options: [
+            {
+              name: "--new-column",
+            },
+            {
+              name: "--rename",
+            },
+            {
+              name: "--country",
+            },
+            {
+              name: "--min-score",
+            },
+            {
+              name: "--admin1",
+            },
+            {
+              name: "--k_weight",
+            },
+            {
+              name: "--formatstr",
+            },
+            {
+              name: "--language",
+            },
+            {
+              name: "--invalid-result",
+            },
+            {
+              name: "--jobs",
+            },
+            {
+              name: "--batch",
+            },
+            {
+              name: "--timeout",
+            },
+            {
+              name: "--cache-dir",
+            },
+            {
+              name: "--languages",
+            },
+            {
+              name: "--cities-url",
+            },
+            {
+              name: "--force",
+            },
+            {
+              name: "--output",
+            },
+            {
+              name: "--delimiter",
+            },
+            {
+              name: "--progressbar",
+            },
+            {
+              name: ["-h", "--help"],
+              description: "Print help",
+            },
+          ],
+        },
         {
           name: "index-load",
           options: [
@@ -1905,6 +2040,12 @@ const completion: Fig.Spec = {
             {
               name: "countryinfonow",
             },
+            {
+              name: "iplookup",
+            },
+            {
+              name: "iplookupnow",
+            },
             {
               name: "index-load",
             },
@@ -1988,6 +2129,30 @@ const completion: Fig.Spec = {
         },
       ],
     },
+    {
+      name: "geoconvert",
+      options: [
+        {
+          name: "--geometry",
+        },
+        {
+          name: "--latitude",
+        },
+        {
+          name: "--longitude",
+        },
+        {
+          name: "--max-length",
+        },
+        {
+          name: "--output",
+        },
+        {
+          name: ["-h", "--help"],
+          description: "Print help",
+        },
+      ],
+    },
     {
       name: "headers",
       options: [
@@ -2330,6 +2495,15 @@ const completion: Fig.Spec = {
         {
           name: "--freeze-columns",
         },
+        {
+          name: "--monochrome",
+        },
+        {
+          name: "--wrap-mode",
+        },
+        {
+          name: "--prompt",
+        },
         {
           name: "--echo-column",
         },
@@ -2546,6 +2720,54 @@ const completion: Fig.Spec = {
         },
       ],
     },
+    {
+      name: "pivotp",
+      options: [
+        {
+          name: "--index",
+        },
+        {
+          name: "--values",
+        },
+        {
+          name: "--agg",
+        },
+        {
+          name: "--sort-columns",
+        },
+        {
+          name: "--col-separator",
+        },
+        {
+          name: "--validate",
+        },
+        {
+          name: "--try-parsedates",
+        },
+        {
+          name: "--infer-len",
+        },
+        {
+          name: "--decimal-comma",
+        },
+        {
+          name: "--ignore-errors",
+        },
+        {
+          name: "--output",
+        },
+        {
+          name: "--delimiter",
+        },
+        {
+          name: "--quiet",
+        },
+        {
+          name: ["-h", "--help"],
+          description: "Print help",
+        },
+      ],
+    },
     {
       name: "pro",
       subcommands: [
@@ -3350,6 +3572,9 @@ const completion: Fig.Spec = {
         {
           name: "--numeric",
         },
+        {
+          name: "--natural",
+        },
         {
           name: "--reverse",
         },
@@ -3446,6 +3671,15 @@ const completion: Fig.Spec = {
         {
           name: "--pad",
         },
+        {
+          name: "--filter",
+        },
+        {
+          name: "--filter-cleanup",
+        },
+        {
+          name: "--filter-ignore-errors",
+        },
         {
           name: "--no-headers",
         },
@@ -3551,6 +3785,9 @@ const completion: Fig.Spec = {
         {
           name: "--infer-boolean",
         },
+        {
+          name: "--boolean-patterns",
+        },
         {
           name: "--mode",
         },
@@ -3566,6 +3803,12 @@ const completion: Fig.Spec = {
         {
           name: "--quartiles",
         },
+        {
+          name: "--percentiles",
+        },
+        {
+          name: "--percentile-list",
+        },
         {
           name: "--round",
         },
@@ -3740,6 +3983,9 @@ const completion: Fig.Spec = {
             {
               name: "--separator",
             },
+            {
+              name: "--all-strings",
+            },
             {
               name: "--jobs",
             },
@@ -3785,6 +4031,9 @@ const completion: Fig.Spec = {
             {
               name: "--separator",
             },
+            {
+              name: "--all-strings",
+            },
             {
               name: "--jobs",
             },
@@ -3830,6 +4079,105 @@ const completion: Fig.Spec = {
             {
               name: "--separator",
             },
+            {
+              name: "--all-strings",
+            },
+            {
+              name: "--jobs",
+            },
+            {
+              name: "--delimiter",
+            },
+            {
+              name: ["-h", "--help"],
+              description: "Print help",
+            },
+          ],
+        },
+        {
+          name: "ods",
+          options: [
+            {
+              name: "--print-package",
+            },
+            {
+              name: "--dump",
+            },
+            {
+              name: "--stats",
+            },
+            {
+              name: "--stats-csv",
+            },
+            {
+              name: "--quiet",
+            },
+            {
+              name: "--schema",
+            },
+            {
+              name: "--drop",
+            },
+            {
+              name: "--evolve",
+            },
+            {
+              name: "--pipe",
+            },
+            {
+              name: "--separator",
+            },
+            {
+              name: "--all-strings",
+            },
+            {
+              name: "--jobs",
+            },
+            {
+              name: "--delimiter",
+            },
+            {
+              name: ["-h", "--help"],
+              description: "Print help",
+            },
+          ],
+        },
+        {
+          name: "parquet",
+          options: [
+            {
+              name: "--print-package",
+            },
+            {
+              name: "--dump",
+            },
+            {
+              name: "--stats",
+            },
+            {
+              name: "--stats-csv",
+            },
+            {
+              name: "--quiet",
+            },
+            {
+              name: "--schema",
+            },
+            {
+              name: "--drop",
+            },
+            {
+              name: "--evolve",
+            },
+            {
+              name: "--pipe",
+            },
+            {
+              name: "--separator",
+            },
+            {
+              name: "--all-strings",
+            },
             {
               name: "--jobs",
             },
@@ -3875,6 +4223,9 @@ const completion: Fig.Spec = {
             {
               name: "--separator",
             },
+            {
+              name: "--all-strings",
+            },
             {
               name: "--jobs",
             },
@@ -3900,6 +4251,12 @@ const completion: Fig.Spec = {
             {
               name: "xlsx",
             },
+            {
+              name: "ods",
+            },
+            {
+              name: "parquet",
+            },
             {
               name: "datapackage",
             },
@@ -3941,6 +4298,9 @@ const completion: Fig.Spec = {
         {
           name: "--separator",
         },
+        {
+          name: "--all-strings",
+        },
         {
           name: "--jobs",
         },
@@ -4013,6 +4373,9 @@ const completion: Fig.Spec = {
         {
           name: "--trim",
         },
+        {
+          name: "--no-format-validation",
+        },
         {
           name: "--fail-fast",
         },
@@ -4189,6 +4552,12 @@ const completion: Fig.Spec = {
             {
               name: "countryinfonow",
             },
+            {
+              name: "iplookup",
+            },
+            {
+              name: "iplookupnow",
+            },
             {
               name: "index-load",
             },
@@ -4203,6 +4572,9 @@ const completion: Fig.Spec = {
             },
           ],
         },
+        {
+          name: "geoconvert",
+        },
         {
           name: "headers",
         },
@@ -4241,6 +4613,9 @@ const completion: Fig.Spec = {
         {
           name: "partition",
         },
+        {
+          name: "pivotp",
+        },
         {
           name: "pro",
           subcommands: [
@@ -4352,6 +4727,12 @@ const completion: Fig.Spec = {
             {
               name: "xlsx",
             },
+            {
+              name: "ods",
+            },
+            {
+              name: "parquet",
+            },
             {
               name: "datapackage",
             },
