@@ -1,11 +1,12 @@
 use clap::{arg, Command};
 
 pub fn luau_cmd() -> Command {
-    Command::new("luau").args([
+    let global_args = [
         arg!(--"no-globals"),
         arg!(--colindex),
         arg!(--remap),
         arg!(--begin),
+        arg!(--end),
         arg!(--"luau-path"),
         arg!(--"max-errors"),
         arg!(--timeout),
@@ -16,5 +17,11 @@ pub fn luau_cmd() -> Command {
         arg!(--"no-headers"),
         arg!(--delimiter),
         arg!(--progressbar),
-    ])
+    ];
+    Command::new("luau")
+        .subcommands([
+            Command::new("map").args(&global_args),
+            Command::new("filter").args(&global_args),
+        ])
+        .args(global_args)
 }
