@@ -6,11 +6,14 @@ pub fn stats_cmd() -> Command {
         arg!(--everything),
         arg!(--typesonly),
         arg!(--"infer-boolean"),
+        arg!(--"boolean-patterns"),
         arg!(--mode),
         arg!(--cardinality),
         arg!(--median),
         arg!(--mad),
         arg!(--quartiles),
+        arg!(--"percentiles"),
+        arg!(--"percentile-list"),
         arg!(--round),
         arg!(--nulls),
         arg!(--"infer-dates"),
