@@ -474,7 +474,7 @@ pub fn polars_count_input(conf: &Config, low_memory: bool) -> CliResult<u64> {
         // do it in a block so schema_df is dropped early
         // Use ignore_errors to handle schema inference issues (e.g., columns that start
         // with boolean values but contain integers later)
-        let schema_df = match LazyCsvReader::new(PlPath::new(&filepath.to_string_lossy()))
+        let schema_df = match LazyCsvReader::new(PlRefPath::new(&*filepath.to_string_lossy()))
             .with_separator(delimiter)
             .with_comment_prefix(comment_prefix.clone())
             .with_n_rows(Some(1))
@@ -507,7 +507,7 @@ pub fn polars_count_input(conf: &Config, low_memory: bool) -> CliResult<u64> {
         // using the LazyCsvReader builder to set CSV read options
         // Use ignore_errors to handle schema inference issues (e.g., columns that start
         // with boolean values but contain integers later)
-        lazy_df = match LazyCsvReader::new(PlPath::new(&filepath.to_string_lossy()))
+        lazy_df = match LazyCsvReader::new(PlRefPath::new(&*filepath.to_string_lossy()))
             .with_separator(delimiter)
             .with_comment_prefix(comment_prefix)
             .with_low_memory(low_memory)
