@@ -9,7 +9,7 @@ flashlight,gray
 
 To output the data with the color of the shoes as green instead of blue, run:
 
-qsv edit items.csv color 0 green
+  $ qsv edit items.csv color 0 green
 
 The following is returned as output:
 
@@ -123,10 +123,8 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
 
     if in_place && let Some(input_path_string) = input {
         let input_path = std::path::Path::new(&input_path_string);
-        if let Some(input_extension_osstr) = input_path.extension() {
-            let mut backup_extension = input_extension_osstr.to_string_lossy().to_string();
-            backup_extension.push_str(".bak");
-            std::fs::rename(input_path, input_path.with_extension(backup_extension))?;
+        if input_path.extension().is_some() {
+            std::fs::rename(input_path, input_path.with_added_extension("bak"))?;
             std::fs::copy(tempfile.path(), input_path)?;
         }
     }
