@@ -859,11 +859,11 @@ impl JoinStruct {
         CsvWriter::new(&mut out_writer)
             .include_header(true)
             .with_separator(out_delim)
-            .with_datetime_format(self.datetime_format)
-            .with_date_format(self.date_format)
-            .with_time_format(self.time_format)
+            .with_datetime_format(self.datetime_format.map(std::convert::Into::into))
+            .with_date_format(self.date_format.map(std::convert::Into::into))
+            .with_time_format(self.time_format.map(std::convert::Into::into))
             .with_float_precision(self.float_precision)
-            .with_null_value(self.null_value)
+            .with_null_value(self.null_value.into())
             .with_decimal_comma(self.decimal_comma)
             .include_bom(util::get_envvar_flag("QSV_OUTPUT_BOM"))
             .finish(&mut results_df)?;
@@ -883,7 +883,7 @@ impl Args {
             args: &Args,
             delim: u8,
         ) -> LazyCsvReader {
-            LazyCsvReader::new(PlPath::new(file_path))
+            LazyCsvReader::new(PlRefPath::new(file_path))
                 .with_has_header(true)
                 .with_missing_is_null(args.flag_nulls)
                 .with_comment_prefix(comment_char.cloned())
