@@ -100,6 +100,31 @@ struct Args {
 
 pub fn run(argv: &[&str]) -> CliResult<()> {
     let mut args: Args = util::get_args(USAGE, argv)?;
+
+    // if no input file is provided, use stdin and save to a temp file
+    if args.arg_input.is_none() {
+        // Get or initialize temp directory that persists until program exit
+        let temp_dir =
+            crate::config::TEMP_FILE_DIR.get_or_init(|| tempfile::TempDir::new().unwrap().keep());
+
+        // Create a temporary file with .csv extension to store stdin input
+        let mut temp_file = tempfile::Builder::new()
+            .suffix(".csv")
+            .tempfile_in(temp_dir)?;
+        io::copy(&mut io::stdin(), &mut temp_file)?;
+
+        // Get path as string, unwrap is safe as temp files are always valid UTF-8
+        let temp_path = temp_file.path().to_str().unwrap().to_string();
+
+        // Keep temp file from being deleted when it goes out of scope
+        // it will be deleted when the program exits when TEMP_FILE_DIR is deleted
+        temp_file
+            .keep()
+            .map_err(|e| format!("Failed to keep temporary stdin file: {e}"))?;
+
+        args.arg_input = Some(temp_path);
+    }
+
     fs::create_dir_all(&args.arg_outdir)?;
 
     // It would be nice to support efficient parallel partitions, but doing
