@@ -560,7 +560,7 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
     }
 
     // Create CSV reader config
-    let mut csv_reader = LazyCsvReader::new(PlPath::new(&args.arg_input))
+    let mut csv_reader = LazyCsvReader::new(PlRefPath::new(&args.arg_input))
         .with_has_header(true)
         .with_try_parse_dates(args.flag_try_parsedates)
         .with_decimal_comma(args.flag_decimal_comma)
@@ -771,9 +771,10 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
         },
         None => Box::new(io::stdout()) as Box<dyn Write>,
     };
+    let datetime_fmt: PlSmallStr = PlSmallStr::from_str("%Y-%m-%d %H:%M:%S");
     CsvWriter::new(&mut writer)
         .include_header(true)
-        .with_datetime_format(Some("%Y-%m-%d %H:%M:%S".to_string()))
+        .with_datetime_format(Some(datetime_fmt))
         .with_separator(delim)
         .finish(&mut pivot_result)?;
 
