@@ -74,7 +74,7 @@ sniff options:
     --pretty-json            Return results in pretty JSON format.
     --save-urlsample <file>  Save the URL sample to a file.
                              Valid only when input is a URL.
-    --timeout <secs>         Timeout when sniffing URLs in seconds.
+    --timeout <secs>         Timeout when sniffing URLs in seconds. If 0, no timeout is used.
                              [default: 30]
     --user-agent <agent>     Specify custom user agent to use when sniffing a CSV on a URL.
                              It supports the following variables - $QSV_VERSION, $QSV_TARGET,
@@ -116,10 +116,9 @@ use indicatif::HumanCount;
 #[cfg(any(feature = "feature_capable", feature = "lite"))]
 use indicatif::{HumanBytes, ProgressBar, ProgressDrawTarget, ProgressStyle};
 use qsv_sniffer::{DatePreference, SampleSize, Sniffer};
-use reqwest::Client;
+use qsv_tabwriter::TabWriter;
 use serde::{Deserialize, Serialize};
 use serde_json::json;
-use tabwriter::TabWriter;
 use tempfile::NamedTempFile;
 use url::Url;
 
@@ -319,20 +318,13 @@ async fn get_file_to_sniff(args: &Args, tmpdir: &tempfile::TempDir) -> CliResult
                 let snappy_flag = url.to_lowercase().ends_with(".sz");
 
                 // setup the reqwest client
-                let client = match Client::builder()
-                    .user_agent(util::set_user_agent(args.flag_user_agent.clone())?)
-                    .brotli(true)
-                    .gzip(true)
-                    .deflate(true)
-                    .use_rustls_tls()
-                    .http2_adaptive_window(true)
-                    .build()
-                {
-                    Ok(c) => c,
-                    Err(e) => {
-                        return fail_clierror!("Cannot build reqwest client: {e}.");
-                    },
-                };
+                let client = util::create_reqwest_async_client(
+                    args.flag_user_agent.clone(),
+                    util::timeout_secs(args.flag_timeout)
+                        .unwrap_or(30)
+                        .min(u16::MAX as u64) as u16,
+                    Some(url.clone()),
+                )?;
 
                 let res = client
                     .get(url.clone())
@@ -774,7 +766,7 @@ async fn sniff_main(mut args: Args) -> CliResult<()> {
                     }
                 });
                 if args.flag_pretty_json {
-                    woutinfo!("{}", serde_json::to_string_pretty(&json_result).unwrap());
+                    woutinfo!("{}", simd_json::to_string_pretty(&json_result).unwrap());
                     return Ok(());
                 }
                 woutinfo!("{json_result}");
@@ -793,7 +785,7 @@ async fn sniff_main(mut args: Args) -> CliResult<()> {
                 }]
             });
             if args.flag_pretty_json {
-                return fail_clierror!("{}", serde_json::to_string_pretty(&json_result).unwrap());
+                return fail_clierror!("{}", simd_json::to_string_pretty(&json_result).unwrap());
             }
             return fail_clierror!("{json_result}");
         }
@@ -998,10 +990,10 @@ async fn sniff_main(mut args: Args) -> CliResult<()> {
             if args.flag_pretty_json {
                 println!(
                     "{}",
-                    serde_json::to_string_pretty(&processed_results).unwrap()
+                    simd_json::to_string_pretty(&processed_results).unwrap()
                 );
             } else {
-                println!("{}", serde_json::to_string(&processed_results).unwrap());
+                println!("{}", simd_json::to_string(&processed_results).unwrap());
             }
             return Ok(());
         }
@@ -1016,22 +1008,21 @@ async fn sniff_main(mut args: Args) -> CliResult<()> {
             }
         });
         let error_msg = if args.flag_pretty_json {
-            serde_json::to_string_pretty(&sniff_error_json).unwrap()
+            simd_json::to_string_pretty(&sniff_error_json).unwrap()
         } else {
-            serde_json::to_string(&sniff_error_json).unwrap()
+            simd_json::to_string(&sniff_error_json).unwrap()
         };
         return fail_clierror!("{error_msg}");
     }
 
-    if sniff_error.is_none() {
-        println!("{processed_results}");
-        Ok(())
-    } else {
+    if let Some(error) = sniff_error {
         fail_clierror!(
             "{error}; size: {size}, last_modified: {last_modified}",
-            error = sniff_error.unwrap(),
             size = sfile_info.file_size,
             last_modified = sfile_info.last_modified
         )
+    } else {
+        println!("{processed_results}");
+        Ok(())
     }
 }
