@@ -53,7 +53,7 @@ impl<R: io::Read + io::Seek, I: io::Read + io::Seek> Indexed<R, I> {
                 i,
                 self.count()
             );
-            return fail!(io::Error::new(io::ErrorKind::Other, msg));
+            return fail!(io::Error::other(msg));
         }
         if self.csv_rdr.has_headers() {
             i += 1;
