@@ -14,17 +14,13 @@ use crate::{
 #[global_allocator]
 static GLOBAL: mimalloc::MiMalloc = mimalloc::MiMalloc;
 
-#[cfg(feature = "tikv-jemallocator")]
-#[global_allocator]
-static GLOBAL: jemallocator::Jemalloc = jemallocator::Jemalloc;
-
 static COMMAND_LIST: &str = r#"
     behead      Drop header from CSV file
     cat         Concatenate by row or column
     count       Count records
     datefmt     Format date/datetime columns
     dedup       Remove redundant rows
-    describegpt Infer extended metadata using a LLM
+    describegpt Infer extended metadata or chat with your data using a LLM
     diff        Find the difference between two CSVs
     edit        Replace a cell's value specified by row and column
     enum        Add a new column enumerating CSV lines
@@ -45,6 +41,7 @@ static COMMAND_LIST: &str = r#"
     join        Join CSV files
     json        Convert JSON to CSV
     jsonl       Convert newline-delimited JSON files to CSV
+    moarstats   Add "moar" statistics to existing stats CSV
     partition   Partition CSV data based on a column value
     pro         Interact with the qsv pro API
     pseudo      Pseudonymise the values of a column
@@ -271,6 +268,7 @@ enum Command {
     SortCheck,
     Split,
     Stats,
+    Moarstats,
     Table,
     Tojsonl,
     Transpose,
@@ -341,6 +339,7 @@ impl Command {
             Command::SortCheck => cmd::sortcheck::run(argv),
             Command::Split => cmd::split::run(argv),
             Command::Stats => cmd::stats::run(argv),
+            Command::Moarstats => cmd::moarstats::run(argv),
             Command::Table => cmd::table::run(argv),
             Command::Tojsonl => cmd::tojsonl::run(argv),
             Command::Transpose => cmd::transpose::run(argv),
