@@ -19,6 +19,25 @@ macro_rules! pivotp_test {
     };
 }
 
+macro_rules! pivotp_maintain_order_test {
+    ($name:ident, $fun:expr_2021) => {
+        mod $name {
+            use std::process;
+
+            #[allow(unused_imports)]
+            use super::setup_maintain_order;
+            use crate::workdir::Workdir;
+
+            #[test]
+            fn main() {
+                let wrk = setup_maintain_order(stringify!($name));
+                let cmd = wrk.command("pivotp");
+                $fun(wrk, cmd);
+            }
+        }
+    };
+}
+
 fn setup(name: &str) -> Workdir {
     // Sample data for testing pivot operations
     let sales = vec![
@@ -36,6 +55,27 @@ fn setup(name: &str) -> Workdir {
     wrk
 }
 
+fn setup_maintain_order(name: &str) -> Workdir {
+    // Sample data for testing pivot operations
+    let sales = vec![
+        svec!["date", "product", "region", "sales"],
+        svec!["2023-01-01", "C", "North", "100"],
+        svec!["2023-01-01", "D", "South", "200"],
+        svec!["2023-01-02", "B", "South", "250"],
+        svec!["2023-01-02", "A", "North", "300"],
+        svec!["2023-01-01", "A", "North", "100"],
+        svec!["2023-01-01", "B", "North", "150"],
+        svec!["2023-01-01", "A", "South", "200"],
+        svec!["2023-01-02", "B", "North", "350"],
+        svec!["2023-01-02", "C", "South", "400"],
+        svec!["2023-01-02", "D", "North", "450"],
+    ];
+
+    let wrk = Workdir::new(name);
+    wrk.create("sales_maintain_order.csv", sales);
+    wrk
+}
+
 // Test basic pivot with single index
 pivotp_test!(pivotp_basic, |wrk: Workdir, mut cmd: process::Command| {
     cmd.args(&[
@@ -215,32 +255,29 @@ pivotp_test!(
     }
 );
 
-// Test pivot with count aggregation
-pivotp_test!(
-    pivotp_count_agg,
-    |wrk: Workdir, mut cmd: process::Command| {
-        cmd.args(&[
-            "product",
-            "--index",
-            "region",
-            "--values",
-            "sales",
-            "--agg",
-            "count",
-            "sales.csv",
-        ]);
+// Test pivot with len aggregation
+pivotp_test!(pivotp_len_agg, |wrk: Workdir, mut cmd: process::Command| {
+    cmd.args(&[
+        "product",
+        "--index",
+        "region",
+        "--values",
+        "sales",
+        "--agg",
+        "len",
+        "sales.csv",
+    ]);
 
-        wrk.assert_success(&mut cmd);
+    wrk.assert_success(&mut cmd);
 
-        let got: Vec<Vec<String>> = wrk.read_stdout(&mut cmd);
-        let expected = vec![
-            svec!["region", "A", "B"],
-            svec!["North", "2", "2"],
-            svec!["South", "1", "1"],
-        ];
-        assert_eq!(got, expected);
-    }
-);
+    let got: Vec<Vec<String>> = wrk.read_stdout(&mut cmd);
+    let expected = vec![
+        svec!["region", "A", "B"],
+        svec!["North", "2", "2"],
+        svec!["South", "1", "1"],
+    ];
+    assert_eq!(got, expected);
+});
 
 // Test pivot with last aggregation
 pivotp_test!(
@@ -269,6 +306,30 @@ pivotp_test!(
     }
 );
 
+// Test pivot with item aggregation
+pivotp_test!(
+    pivotp_item_agg,
+    |wrk: Workdir, mut cmd: process::Command| {
+        cmd.args(&[
+            "product",
+            "--index",
+            "region",
+            "--values",
+            "sales",
+            "--agg",
+            "item",
+            "sales.csv",
+        ]);
+
+        wrk.assert_err(&mut cmd);
+
+        let msg = wrk.output_stderr(&mut cmd);
+        let expected_msg = "Polars error: ComputeError(ErrString(\"aggregation 'item' expected no \
+                            or a single value, got 2 values\"))\n";
+        assert_eq!(msg, expected_msg);
+    }
+);
+
 // Test pivot with sorted columns
 pivotp_test!(
     pivotp_sort_columns,
@@ -297,6 +358,63 @@ pivotp_test!(
     }
 );
 
+// Test pivot with maintain-order flag
+pivotp_maintain_order_test!(
+    pivotp_maintain_order,
+    |wrk: Workdir, mut cmd: process::Command| {
+        cmd.args(&[
+            "product",
+            "--index",
+            "date",
+            "--values",
+            "sales",
+            "--maintain-order",
+            "--agg",
+            "first",
+            "sales_maintain_order.csv",
+        ]);
+
+        wrk.assert_success(&mut cmd);
+
+        let got: Vec<Vec<String>> = wrk.read_stdout(&mut cmd);
+        let expected = vec![
+            svec!["date", "C", "D", "B", "A"],
+            svec!["2023-01-01", "100", "200", "150", "100"],
+            svec!["2023-01-02", "400", "450", "250", "300"],
+        ];
+        assert_eq!(got, expected);
+    }
+);
+
+// Test pivot with maintain-order flag
+pivotp_maintain_order_test!(
+    pivotp_maintain_order_and_sort_columns,
+    |wrk: Workdir, mut cmd: process::Command| {
+        cmd.args(&[
+            "product",
+            "--index",
+            "date",
+            "--values",
+            "sales",
+            "--maintain-order",
+            "--sort-columns",
+            "--agg",
+            "first",
+            "sales_maintain_order.csv",
+        ]);
+
+        wrk.assert_success(&mut cmd);
+
+        let got: Vec<Vec<String>> = wrk.read_stdout(&mut cmd);
+        let expected = vec![
+            svec!["date", "A", "B", "C", "D"],
+            svec!["2023-01-01", "100", "150", "100", "200"],
+            svec!["2023-01-02", "300", "250", "400", "450"],
+        ];
+        assert_eq!(got, expected);
+    }
+);
+
 // Test pivot with custom column separator
 pivotp_test!(
     pivotp_col_separator,
